==> igniteui-angular-excel-14.2.0.tgz: package/esm5/lib/WorksheetRegion_HorizontalWeakSorter.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-angular-core";
import { IComparer$1_$type } from "igniteui-angular-core";
import { WeakReference } from "igniteui-angular-core";
import { ExcelUtils } from "./ExcelUtils";
import { WorksheetRegion_HorizontalSorter } from "./WorksheetRegion_HorizontalSorter";
/**
 * @hidden
 */
var WorksheetRegion_HorizontalWeakSorter = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WorksheetRegion_HorizontalWeakSorter, _super);
    function WorksheetRegion_HorizontalWeakSorter() {
        return _super.call(this) || this;
    }
    WorksheetRegion_HorizontalWeakSorter.prototype.compare = function (a, b) {
        var c = ExcelUtils.dy(a);
        var d = ExcelUtils.dy(b);
        if (c == null && d == null) {
            return 0;
        }
        if (c == null) {
            return -1;
        }
        if (d == null) {
            return 1;
        }
        return WorksheetRegion_HorizontalSorter._a.compare(c, d);
    };
    WorksheetRegion_HorizontalWeakSorter.$t = markType(WorksheetRegion_HorizontalWeakSorter, 'WorksheetRegion_HorizontalWeakSorter', Base.$, [IComparer$1_$type.specialize(WeakReference.$)]);
    WorksheetRegion_HorizontalWeakSorter._a = new WorksheetRegion_HorizontalWeakSorter();
    return WorksheetRegion_HorizontalWeakSorter;
}(Base));
export { WorksheetRegion_HorizontalWeakSorter };

==> igniteui-angular-excel-18.1.1.tgz: package/esm5/lib/WorksheetRegion_HorizontalWeakSorter.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, markType } from "igniteui-angular-core";
import { IComparer$1_$type } from "igniteui-angular-core";
import { WeakReference } from "igniteui-angular-core";
import { ExcelUtils } from "./ExcelUtils";
import { WorksheetRegion_HorizontalSorter } from "./WorksheetRegion_HorizontalSorter";
/**
 * @hidden
 */
var WorksheetRegion_HorizontalWeakSorter = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WorksheetRegion_HorizontalWeakSorter, _super);
    function WorksheetRegion_HorizontalWeakSorter() {
        return _super.call(this) || this;
    }
    WorksheetRegion_HorizontalWeakSorter.prototype.compare = function (a, b) {
        var c = ExcelUtils.d0(a);
        var d = ExcelUtils.d0(b);
        if (c == null && d == null) {
            return 0;
        }
        if (c == null) {
            return -1;
        }
        if (d == null) {
            return 1;
        }
        return WorksheetRegion_HorizontalSorter._a.compare(c, d);
    };
    WorksheetRegion_HorizontalWeakSorter.$t = markType(WorksheetRegion_HorizontalWeakSorter, 'WorksheetRegion_HorizontalWeakSorter', Base.$, [IComparer$1_$type.specialize(WeakReference.$)]);
    WorksheetRegion_HorizontalWeakSorter._a = new WorksheetRegion_HorizontalWeakSorter();
    return WorksheetRegion_HorizontalWeakSorter;
}(Base));
export { WorksheetRegion_HorizontalWeakSorter };
